@@ -134,7 +134,7 @@ class EbookList(gtk.ListStore):
                         if m:
                             g = m.groupdict()
                             entry = (reformat_auth(g.get('auth', author_name)),
-                                     reformat_title(g.get('titl', base)),
+                                     g.get('titl', base),
                                      g.get('lang', ''),
                                      full_path)
                             break
@@ -145,9 +145,6 @@ class EbookList(gtk.ListStore):
         def reformat_auth(auth):
             return auth.replace("; ", "\n")
 
-        def reformat_title(title):
-            return title.replace("; ", "\n")
-
         def really_add(r):
             for x in r:
                 self.append(x)
@@ -314,19 +311,15 @@ def transpose_articles(text):
                 parts[0] = p.strip()
     return u"\n".join(parts).strip()
 
-def ellipsize(text, max_length=80, ellipsis=u"..."):
+def ellipsize(text, max_length=80):
     pieces = text.split(" ")
     size = -1
     for k, piece in enumerate(pieces):
-        if size + 1 + len(piece) + len(ellipsis) > max_length:
+        if size + 1 + len(piece) + 4 > max_length:
             if size > 0:
-                return u" ".join(pieces[:k]) + ellipsis
+                return u" ".join(pieces[:k]) + u" ..."
             else:
-                rem = max_length - len(ellipsis)
-                if rem >= 0:
-                    return pieces[0][:rem] + ellipsis
-                else:
-                    return ellipsis[:max_length]
+                return pieces[0][:125] + u"..."
         size += len(piece) + 1
     return u" ".join(pieces)
 
@@ -373,8 +366,6 @@ class DownloadInfo(gtk.ListStore):
                                  if not x.startswith('tr. ')])
         base_author = clean_filename(base_author)
 
-        title = self.title.replace("\n", "; ")
-
         url_base = url.split('/')[-1]
         try:
             ext = url_base.split('.', 1)[1]
@@ -387,12 +378,12 @@ class DownloadInfo(gtk.ListStore):
 
         if self.author and self.title and self.language:
             base_name = u"%s - %s [%s]" % (author,
-                                           title,
+                                           self.title,
                                            self.language.lower())
         elif self.author and self.title:
-            base_name = u"%s - %s" % (author, title)
+            base_name = u"%s - %s" % (author, self.title)
         elif self.title:
-            base_name = u"%s" % title
+            base_name = u"%s" % self.title
         else:
             base_name = u"Etext %d" % self.etext_id
         
@@ -405,8 +396,6 @@ class DownloadInfo(gtk.ListStore):
         else:
             file_name = clean_filename(base_name)
 
-        file_name = trim_filename(file_name, max_length=255)
-
         if base_author:
             path = os.path.join(base_directory, base_author, file_name)
         else:
@@ -443,25 +432,6 @@ class DownloadInfo(gtk.ListStore):
         
         run_in_background(do_download, url, callback=on_finish)
 
-def trim_filename(fn, max_length=255):
-    if len(fn) <= max_length:
-        return fn
-
-    m = re.match(ur'^(.*?)(\.[a-zA-Z0-9.]+)$', fn)
-    if m:
-        base = m.group(1)
-        ext = m.group(2)
-    else:
-        base = fn
-        ext = u""
-
-    max_base_length = max_length - len(ext)
-    if max_base_length < 0:
-        max_base_length = 0
-
-    base = ellipsize(fn, max_length=max_base_length, ellipsis=u"\u2026")
-    return base + ext
-
 def clean_filename(s):
     """
     Encode file name in filesystem charset and remove illegal characters
